/* 

Copyright (C) 2003-2004 Yves Schmid (www.garagecube.com)

Author(s): Yves Schmid

This program is free software; you can redistribute it and/or modify it under the terms of the GNU General Public License as published by the Free Software Foundation; either version 2 of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the     GNU General Public License for more details.

You should have received a copy of the GNU General Public Licensealong with this program; if not, write to the Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/

#ifndef Cosmic_OpenGLView_H
#define Cosmic_OpenGLView_H

#import <Cocoa/Cocoa.h>
#import <Quicktime/Quicktime.h>

@class CosmicPalette;

// Define the OMT basic classes

class OMediaPureGLRenderTarget;
class OMediaWorld;
class OMediaViewPort;
class OMediaLayer;
class OMediaCanvas;
class OMediaCanvasElement;
class OMediaTimer;
class OMediaElement;

class CosmicMovieCompress
{
	public:

    Movie theMovie;
	Media theMedia;
	Track theTrack;
    short resRefNum;
	
	float frameRate;

	GWorldPtr theGWorld,previousGWorld;
	Handle compressedData;
	Ptr compressedDataPtr;
	ImageDescriptionHandle imageDesc;
	
	ImageSequence			imageSequence;
};

#define COSMIC_GRID_SIZE 12

// The class

@interface CosmicOpenGLView : NSOpenGLView
{
	CosmicPalette				*palette;

    OMediaPureGLRenderTarget	*renderTarget;

    OMediaWorld			*world;
    OMediaViewPort		*viewport;
	
	OMediaLayer			*layer;
	OMediaCanvasElement *canvasElement[COSMIC_GRID_SIZE][COSMIC_GRID_SIZE];
	OMediaCanvas		*canvas;
	
	unsigned long		*undoBuffer;
	BOOL				undoBufferFilled;
	
	OMediaCanvas		*crossCanvas;
	OMediaCanvasElement *crossCanvasElement;

	OMediaCanvas		*bufferBorderCanvas;
	OMediaCanvasElement *bufferCanvasElement;
	
	BOOL				mouseIsDown,keyWindowChanged;
	BOOL				connectLines;
		
	float				rotationSpeed,handRotate,baseHandRotate;
	
	float				scrollSpeed;
	float				baseHandMoveX,baseHandMoveY;

	float				scaleSpeed;
	float				baseHandScaleY,tempHandScale;
	float				scaleEnd,scaleStart,scalePingpongReverse;
	bool				scalePingpong;

		
	float				colorInterpolateState;
	
	OMediaElement		*lastPickedElement;
	int					lastX,lastY,lastEX,lastEY;
	BOOL				mouseDownFirstDraw;
	BOOL				threadTerminated;
	BOOL				stopAll;
	BOOL				initialized;
	
	BOOL				paintDisableAutoTiledDraw;
	
		
	double				wantedRate;
	double				fpsFactor;
	
	NSTimer				*mainThreadTimer,*updateUITimer;	
	
	BOOL					recordMode;
	CosmicMovieCompress		*movieRecord;
	int						nframesToCompress,totalFramesToCompress;
	double					exportMovieFps;
}

- (void)lock;
- (void)unlock;

- (void)paintBrush:(BOOL)quiet;

-(IBAction)doExportMovie:(id)sender;
-(IBAction)cancelExportMovie:(id)sender;

-(IBAction)resetAnimVectors:(id)sender;

-(IBAction)rotationSpeedChanged:(id)sender;
-(IBAction)scrollSpeedChanged:(id)sender;
-(IBAction)scaleSpeedChanged:(id)sender;

-(IBAction)stopRotation:(id)sender;
-(IBAction)stopScroll:(id)sender;
-(IBAction)stopScale:(id)sender;

-(IBAction)mirrorDocument:(id)sender;

-(void)flushCanvasGLTexture;

-(void)stopAndReleaseAll;

-(void)enterRecordMode:(NSString*)pathname;
-(void)exitRecordMode;

-(BOOL)initMovieCompression:(NSString*)path;
-(void)finishMovieCompression;
-(void)addFrameToMovieCompression:(OMediaCanvas*)mcanvas;

-(IBAction)abortExportMovie:(id)sender;

-(IBAction)pingPongChanged:(id)sender;


@end


#endif


